// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KDSINGLEAPPLICATION_VERSION_H
#define KDSINGLEAPPLICATION_VERSION_H

#define KDSINGLEAPPLICATION_VERSION_STRING "1.1.0"
#define KDSINGLEAPPLICATION_VERSION_MAJOR 1
#define KDSINGLEAPPLICATION_VERSION_MINOR 1
#define KDSINGLEAPPLICATION_VERSION_PATCH 0
#define KDSINGLEAPPLICATION_VERSION KDSINGLEAPPLICATION_VERSION_CHECK(KDSINGLEAPPLICATION_VERSION_MAJOR, KDSINGLEAPPLICATION_VERSION_MINOR, KDSINGLEAPPLICATION_VERSION_PATCH)

/*
   for example: KDSINGLEAPPLICATION_VERSION >= KDSINGLEAPPLICATION_VERSION_CHECK(1, 2, 2))
*/
#define KDSINGLEAPPLICATION_VERSION_CHECK(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

#endif
